@@ -18,9 +18,7 @@ use super::{
 use atuin_client::{
     database::{Database, current_context},
     history::{History, HistoryId, HistoryStats, store::HistoryStore},
-    settings::{
-        CursorStyle, ExitMode, FilterMode, KeymapMode, PreviewStrategy, SearchMode, Settings,
-    },
+    settings::{CursorStyle, ExitMode, KeymapMode, PreviewStrategy, SearchMode, Settings},
 };
 
 use crate::command::client::search::history_list::HistoryHighlighter;
@@ -920,7 +918,7 @@ impl State {
         let title = if self.update_needed.is_some() {
             let error_style: Style = theme.get_error().into();
             Paragraph::new(Text::from(Span::styled(
-                format!("Atuin v{VERSION} - UPGRADE"),
+                format!("Atuin v{VERSION} - UPDATE"),
                 error_style.add_modifier(Modifier::BOLD),
             )))
         } else {
@@ -1260,9 +1258,7 @@ pub async fn history(
             filter_mode: settings
                 .filter_mode_shell_up_key_binding
                 .filter(|_| settings.shell_up_key_binding)
-                .or_else(|| Some(settings.default_filter_mode()))
-                .filter(|&x| x != FilterMode::Workspace || context.git_root.is_some())
-                .unwrap_or(FilterMode::Global),
+                .unwrap_or_else(|| settings.default_filter_mode(context.git_root.is_some())),
             context,
         },
         engine: engines::engine(search_mode),
@@ -1355,7 +1351,9 @@ pub async fn history(
                 }
             }
             update_needed = &mut update_needed => {
-                app.update_needed = update_needed?;
+                // Don't fail interactive search if update check fails
+                // The update check is a nice-to-have feature, not critical
+                app.update_needed = update_needed.ok().flatten();
             }
         }
 
@@ -1410,18 +1408,22 @@ pub async fn history(
         terminal.clear()?;
     }
 
+    let accept = accept
+        && matches!(
+            Shell::from_env(),
+            Shell::Zsh | Shell::Fish | Shell::Bash | Shell::Xonsh | Shell::Nu | Shell::Powershell
+        );
+
+    let accept_prefix = "__atuin_accept__:";
+
     match result {
         InputAction::AcceptInspecting => {
             match inspecting {
                 Some(result) => {
                     let mut command = result.command;
-                    if accept
-                        && matches!(
-                            Shell::from_env(),
-                            Shell::Zsh | Shell::Fish | Shell::Bash | Shell::Xonsh | Shell::Nu
-                        )
-                    {
-                        command = String::from("__atuin_accept__:") + &command;
+
+                    if accept {
+                        command = String::from(accept_prefix) + &command;
                     }
 
                     // index is in bounds so we return that entry
@@ -1435,13 +1437,8 @@ pub async fn history(
 
             if is_command_chaining {
                 command = format!("{} {}", original_query.trim_end(), command);
-            } else if accept
-                && matches!(
-                    Shell::from_env(),
-                    Shell::Zsh | Shell::Fish | Shell::Bash | Shell::Xonsh | Shell::Nu
-                )
-            {
-                command = String::from("__atuin_accept__:") + &command;
+            } else if accept {
+                command = String::from(accept_prefix) + &command;
             }
 
             // index is in bounds so we return that entry
