@@ -3,7 +3,8 @@ use std::{env, time::Duration};
 use atuin_client::api_client;
 use atuin_common::utils::uuid_v7;
 use atuin_server::{Settings as ServerSettings, launch_with_tcp_listener};
-use atuin_server_postgres::{Postgres, PostgresSettings};
+use atuin_server_database::DbSettings;
+use atuin_server_postgres::Postgres;
 use futures_util::TryFutureExt;
 use tokio::{net::TcpListener, sync::oneshot, task::JoinHandle};
 use tracing::{Dispatch, dispatcher};
@@ -29,13 +30,17 @@ pub async fn start_server(path: &str) -> (String, oneshot::Sender<()>, JoinHandl
         host: "127.0.0.1".to_owned(),
         port: 0,
         path: path.to_owned(),
+        sync_v1_enabled: true,
         open_registration: true,
         max_history_length: 8192,
         max_record_size: 1024 * 1024 * 1024,
         page_size: 1100,
         register_webhook_url: None,
         register_webhook_username: String::new(),
-        db_settings: PostgresSettings { db_uri },
+        db_settings: DbSettings {
+            db_uri: db_uri,
+            read_db_uri: None,
+        },
         metrics: atuin_server::settings::Metrics::default(),
         tls: atuin_server::settings::Tls::default(),
         mail: atuin_server::settings::Mail::default(),
